<?php
/**
 * Palmeria Theme Customizer
 *
 * @package Palmeria
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function palmeria_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'palmeria_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'palmeria_customize_partial_blogdescription',
		) );
	}

    $wp_customize->add_panel('palmeria_theme_options', array(
        'title' => esc_html__('Theme Options', 'palmeria')
    ));
    $wp_customize->add_section('palmeria_blog', array(
        'title' => esc_html__('Blog Options', 'palmeria'),
        'panel' => 'palmeria_theme_options'
    ));
    $wp_customize->add_setting('palmeria_blog_layout', array(
        'default' => PALMERIA_BLOG_LAYOUT_2,
        'transport' => 'refresh',
        'type' => 'theme_mod',
        'sanitize_callback' => 'palmeria_sanitize_select'

    ));
    $wp_customize->add_control('palmeria_blog_layout', array(
        'label' => esc_html__('Blog Layout', 'palmeria'),
        'type' => 'select',
        'section' => 'palmeria_blog',
        'choices' => array(
            PALMERIA_BLOG_LAYOUT_1 => esc_html__('Classic Wide', 'palmeria'),
            PALMERIA_BLOG_LAYOUT_2 => esc_html__('Classic Boxed', 'palmeria'),
        ),
        'settings' => 'palmeria_blog_layout'

    ));

    /**
     * Booking settings
     */
    if(class_exists('HotelBookingPlugin')) {

        $wp_customize->add_section('palmeria_booking', array(
            'title' => esc_html__('Booking Options', 'palmeria'),
            'panel' => 'palmeria_theme_options'
        ));
        $wp_customize->add_setting('palmeria_accommodation_list_layout', array(
            'default' => PALMERIA_ACCOMMODATION_LIST_LAYOUT_2,
            'transport' => 'refresh',
            'type' => 'theme_mod',
            'sanitize_callback' => 'palmeria_sanitize_select'

        ));
        $wp_customize->add_control('palmeria_accommodation_list_layout', array(
            'label' => esc_html__('Rooms List Layout', 'palmeria'),
            'type' => 'select',
            'section' => 'palmeria_booking',
            'choices' => array(
                PALMERIA_ACCOMMODATION_LIST_LAYOUT_1 => esc_html__('Classic', 'palmeria'),
                PALMERIA_ACCOMMODATION_LIST_LAYOUT_2 => esc_html__('Masonry', 'palmeria'),
            ),
            'settings' => 'palmeria_accommodation_list_layout'

        ));
        $wp_customize->add_setting('palmeria_search_accommodation_list_layout', array(
            'default' => PALMERIA_ACCOMMODATION_LIST_LAYOUT_2,
            'transport' => 'refresh',
            'type' => 'theme_mod',
            'sanitize_callback' => 'palmeria_sanitize_select'

        ));
        $wp_customize->add_control('palmeria_search_accommodation_list_layout', array(
            'label' => esc_html__('Search Result Rooms List Layout', 'palmeria'),
            'type' => 'select',
            'section' => 'palmeria_booking',
            'choices' => array(
                PALMERIA_ACCOMMODATION_LIST_LAYOUT_1 => esc_html__('Classic', 'palmeria'),
                PALMERIA_ACCOMMODATION_LIST_LAYOUT_2 => esc_html__('Masonry', 'palmeria'),
            ),
            'settings' => 'palmeria_search_accommodation_list_layout'

        ));
    }



}
add_action( 'customize_register', 'palmeria_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function palmeria_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function palmeria_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function palmeria_customize_preview_js() {
	wp_enqueue_script( 'palmeria-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), palmeria_get_theme_version(), true );
}
add_action( 'customize_preview_init', 'palmeria_customize_preview_js' );

function palmeria_sanitize_select( $input, $setting ){

    //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
    $input = sanitize_key($input);

    //get the list of possible select options
    $choices = $setting->manager->get_control( $setting->id )->choices;

    //return input if valid or return default option
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

}
